==> zen-cart-v1.2.0-l10n-jp-2.zip: zen-cart-v1.2.0-l10n-jp-2/admin/includes/languages/japanese/specials.php <==
<?php
//
// +----------------------------------------------------------------------+
// |zen-cart Open Source E-commerce                                       |
// +----------------------------------------------------------------------+
// | Copyright (c) 2003 The zen-cart developers                           |
// |                                                                      |
// | http://www.zen-cart.com/index.php                                    |
// |                                                                      |
// | Portions Copyright (c) 2003 osCommerce                               |
// +----------------------------------------------------------------------+
// | This source file is subject to version 2.0 of the GPL license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available through the world-wide-web at the following url:           |
// | http://www.zen-cart.com/license/2_0.txt.                             |
// | If you did not receive a copy of the zen-cart license and are unable |
// | to obtain it through the world-wide-web, please send a note to       |
// | license@zen-cart.com so we can mail you a copy immediately.          |
// +----------------------------------------------------------------------+
//  $Id: specials.php,v 1.8 2005/01/12 09:07:07 shida Exp $
//

define('HEADING_TITLE', 'òʤδ');

define('TABLE_HEADING_PRODUCTS', '̾');
define('TABLE_HEADING_PRODUCTS_MODEL','Model');
define('TABLE_HEADING_PRODUCTS_PRICE', ' /ò/');
define('TABLE_HEADING_PRODUCTS_PERCENTAGE','ѡ');
define('TABLE_HEADING_AVAILABLE_DATE', '󶡲ǽ');
define('TABLE_HEADING_EXPIRES_DATE','λ');
define('TABLE_HEADING_STATUS', 'ơ');
define('TABLE_HEADING_ACTION', '');

define('TEXT_SPECIALS_PRODUCT', '̾:');
define('TEXT_SPECIALS_SPECIAL_PRICE', 'ò:');
define('TEXT_SPECIALS_EXPIRES_DATE', 'λ:');
define('TEXT_SPECIALS_AVAILABLE_DATE', '󶡲ǽ:');
define('TEXT_SPECIALS_PRICE_TIP', '<b>:</b><ul><li>ΨѡȤϤǤޤ㡧<b>20%</b></li><li>ʤϤˤϡ\'.\'ǶڤäƤ㡧<b>49.99</b></li><li>֤ꤷʤϡֽλפ̤ΤޤޤˤƤƤ</li></ul>');

define('TEXT_INFO_DATE_ADDED', 'Ͽ');
define('TEXT_INFO_LAST_MODIFIED', '');
define('TEXT_INFO_NEW_PRICE', 'ʡ');
define('TEXT_INFO_ORIGINAL_PRICE', 'βʡ');
define('TEXT_INFO_DISPLAY_PRICE', 'ɽʡ<br />');
define('TEXT_INFO_AVAILABLE_DATE', '󶡲ǽ');
define('TEXT_INFO_EXPIRES_DATE', '󶡽λ');
define('TEXT_INFO_STATUS_CHANGE', 'ơѹ');
define('TEXT_IMAGE_NONEXISTENT', '¸ߤޤ');

define('TEXT_INFO_HEADING_DELETE_SPECIALS', 'òʤ');
define('TEXT_INFO_DELETE_INTRO', 'òʤ˺ޤ?');
?>

==> zen-cart-v1.3.0.2-l10n-jp-2.zip: zen-cart-v1.3.0.2-l10n-jp-2/admin/includes/languages/japanese/specials.php <==
<?php
//
// +----------------------------------------------------------------------+
// |zen-cart Open Source E-commerce                                       |
// +----------------------------------------------------------------------+
// | Copyright (c) 2003 The zen-cart developers                           |
// |                                                                      |
// | http://www.zen-cart.com/index.php                                    |
// |                                                                      |
// | Portions Copyright (c) 2003 osCommerce                               |
// +----------------------------------------------------------------------+
// | This source file is subject to version 2.0 of the GPL license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available through the world-wide-web at the following url:           |
// | http://www.zen-cart.com/license/2_0.txt.                             |
// | If you did not receive a copy of the zen-cart license and are unable |
// | to obtain it through the world-wide-web, please send a note to       |
// | license@zen-cart.com so we can mail you a copy immediately.          |
// +----------------------------------------------------------------------+
//  $Id: specials.php 1105 2005-04-04 22:05:35Z birdbrain $
//

define('HEADING_TITLE', 'òʤδ');

define('TABLE_HEADING_PRODUCTS', '̾');
define('TABLE_HEADING_PRODUCTS_MODEL','');
define('TABLE_HEADING_PRODUCTS_PRICE', 'ʲ/ò/');
define('TABLE_HEADING_PRODUCTS_PERCENTAGE','ѡ');
define('TABLE_HEADING_AVAILABLE_DATE', '󶡳');
define('TABLE_HEADING_EXPIRES_DATE','󶡽λ');
define('TABLE_HEADING_STATUS', 'ơ');
define('TABLE_HEADING_ACTION', '');

define('TEXT_SPECIALS_PRODUCT', '̾:');
define('TEXT_SPECIALS_SPECIAL_PRICE', 'ò:');
define('TEXT_SPECIALS_EXPIRES_DATE', '󶡽λ:');
define('TEXT_SPECIALS_AVAILABLE_DATE', '󶡳:');
define('TEXT_SPECIALS_PRICE_TIP', '<b>:</b><ul><li>ΨѡȤϤǤޤ㡧<b>20%</b></li><li>ʤϤˤϡ\'.\'ǶڤäƤ㡧<b>49.99</b></li><li>֤ꤷʤϡֽλפ̤ΤޤޤˤƤƤ</li></ul>');

define('TEXT_INFO_DATE_ADDED', 'Ͽ');
define('TEXT_INFO_LAST_MODIFIED', '');
define('TEXT_INFO_NEW_PRICE', 'ʡ');
define('TEXT_INFO_ORIGINAL_PRICE', 'βʡ');
define('TEXT_INFO_DISPLAY_PRICE', 'ɽʡ<br />');
define('TEXT_INFO_AVAILABLE_DATE', '󶡳');
define('TEXT_INFO_EXPIRES_DATE', '󶡽λ');
define('TEXT_INFO_STATUS_CHANGE', 'ơѹ');
define('TEXT_IMAGE_NONEXISTENT', '¸ߤޤ');

define('TEXT_INFO_HEADING_DELETE_SPECIALS', 'òʤ');
define('TEXT_INFO_DELETE_INTRO', 'òʤ˺ޤ?');
?>
